iOSPreferPlist property
When true, the Google Sign In plugin will use the GoogleService-Info.plist
for configuration instead of the clientId parameter.
Implementation
final bool iOSPreferPlist;
When true, the Google Sign In plugin will use the GoogleService-Info.plist
for configuration instead of the clientId parameter.
final bool iOSPreferPlist;