onCredentialReceived abstract method

void onCredentialReceived(
  1. OAuthCredential credential,
  2. AuthAction action
)
inherited

A method that is called when the user has successfully completed the authentication process and decides what to do with the obtained credential.

linkWithCredential and respectful lifecycle hooks are called if action is AuthAction.link.

signInWithCredential and respectful lifecycle hooks are called if action is AuthAction.signIn.

FirebaseAuth.createUserWithEmailAndPassword and respectful lifecycle hooks are called if action is AuthAction.signUp.

Implementation

void onCredentialReceived(fba.OAuthCredential credential, AuthAction action);